
## CATO-CLI - mutation.admin.removeServicePrincipalAdmin:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.admin.removeServicePrincipalAdmin) for documentation on this operation.

### Usage for mutation.admin.removeServicePrincipalAdmin:

`catocli mutation admin removeServicePrincipalAdmin -h`

`catocli mutation admin removeServicePrincipalAdmin <json>`

`catocli mutation admin removeServicePrincipalAdmin "$(cat < mutation.admin.removeServicePrincipalAdmin.json)"`

`catocli mutation admin removeServicePrincipalAdmin '{"adminID":"id"}'`

`catocli mutation admin removeServicePrincipalAdmin -p '{
    "adminID": "id"
}'`


#### Operation Arguments for mutation.admin.removeServicePrincipalAdmin ####

`accountId` [ID] - (required) N/A    
`adminID` [ID] - (required) N/A    
